/*************************************************************
 *** Looking across industries for productivity-employment  
 ***   correlations. Printing the table of correlations.    
 ***   Information appears in Table 1.        
 *** INPUT mypanel.sas7bdat (formed from longpanel.sas7bdat)              
 ***------------------------------------------------------- 
 *** Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372.
 *** By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)           
 ***------------------------------------------------------- 
 *** This is a SAS9 file.                                   
 *************************************************************/

libname DATA '../data/' access=readonly;


************four data panels from CM;
data temp; 
  set DATA.mypanel(where=(year in (1982,1987,1992,1997))
                       keep=year sic87 wt te th r_llpq r_ltfp llpq ltfp);
  sic2 = floor(sic87/100);
  log_te = log(te);
run; 

proc sort data=temp;
  by sic2;
run; 

proc corr data=temp;   ***corr(te,log_prod) for all manufacturing;
   var log_te;
   with r_llpq r_ltfp;
   weight wt;
   title "Corr(log_te,log_rtfp) in Manufacturing";
run; 



   ***previous residual productivities were computed for all manufacturing as a whole;
   ***finding residual productivity for 2digit industries separately;
proc glm data=temp(drop=r_llpq r_ltfp) noprint;
   by sic2;
   class year;
   model llpq ltfp = year;
   output out=temp_r residual=r_llpq r_ltfp;
   weight wt;
quit;
run;

proc corr data=temp_r outp=tcorr noprint;  **corr(log_te,log_prod) for each industry;
   by sic2;
   var log_te;
   with r_llpq r_ltfp;
   weight wt;
   title;
run; 

   ****putting data back together;
data t1 t2;   
   set tcorr(where=(_TYPE_='CORR'));
   if _NAME_='r_llpq' then output t1;
   if _NAME_='r_ltfp' then output t2;
run;

data tcorr(drop=_NAME_ _TYPE_);
   merge t1(rename=(log_te=r_llpq)) t2(rename=(log_te=r_ltfp));
   by sic2;
run;

   ***reporting;
proc print data=tcorr;
   title "Corr(log_te,log_rtfp) within 2-digit SICs";
run;

