%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Estimating the parameters of demand function for concrete using    
%%    nonlinear least-squares.                                         
%% --------------------------------------------------------------------
%%   Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372...                  
%%  By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)                       
%% --------------------------------------------------------------------
%%  This is an Octave m-file (www.octave.org)        
%%  Can be run in MATLAB with some minor changes.                  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;

%----------------reading scatter data for all plants------
data = dlmread('../data/concrete.csv',",",1,0);
phi = data(:,3)/4.92;   %productivity indexes
x = data(:,4);     %sizes
w = data(:,1);
n=sum(w);

wage=5;

iphi=w.*wage./phi;
iphi2=w.*(wage./phi).^2;
iphi3=w.*(wage./phi).^3;
iphi4=w.*(wage./phi).^4;

%-----estimating parameters
p0 = (sum(iphi3)*sum(x.*iphi2)-sum(iphi4)*sum(x.*iphi))/...
     (sum(iphi2)*sum(x.*iphi2)-sum(iphi3)*sum(x.*iphi));
p1 = .5*(p0*sum(iphi2)-sum(iphi3))/sum(x.*iphi);

%-----computing estimation error
x_p = .5*(p0-1./phi)/p1./phi;
err = x-x_p;
sigma = sqrt(sum(w.*err.*err)/n); 
J = [.5*iphi./w/p1, -.5*(p0-iphi./w).*iphi./w/p1^2];
p_sigma = sigma^2*inv(J'*J);
p_sigma = sqrt(p_sigma);

%------displaying results
disp(sprintf("The estimated demand is p=%6.4f-%6.4fq",p0,p1));
disp(sprintf("Standard deviation of error is %f",sigma));
disp("Covariance matrix of coefficient errors is:");
p_sigma
