%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Productivity-size relationship with a linear demand function.     
%%    Plots Figure.2                                                 
%% --------------------------------------------------------------------
%%   Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372...                  
%%  By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)                       
%% --------------------------------------------------------------------
%%  This is an Octave m-file (www.octave.org)        
%%  Requires esptk package (epstk.de)
%%  Can be run in MATLAB with some minor changes.                  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;

%---parameters
global A1=201.85; 
global gamma=29.52; 
global L; 
global w=4; 

%%productivity range
phis=logspace(-3,1,200);

function pr=epi(phi);
   global A1 gamma L w;
   pr = L/4/gamma*(A1-w/phi)^2 * exp(-phi); 
endfunction;


%%%productivity size relations for Lav 
L=1
q1 = max(.5/gamma*(A1-w./phis),0);
x1 = q1./phis;

ce = quad('epi',w/A1,inf)

disp('Changing market size');

%%%productivity size relation for smaller markets 
L=.1;
stop=0;
   %--simple search, increasing A until equilibrium
do;
  A1=A1*1.01;
  ce1 = quad('epi',w/A1,inf);
  if ce1>=ce, stop=1; endif;
until(stop);
A1

q2 = max(.5*L/gamma*(A1-w./phis),0);
x2 = q2./phis;


%%%productivity size relation for larger markets
L=10;
stop=0;
   %--simple search, decreasing A until equilibrium
do;
  A1=.99*A1;
  ce1 = quad('epi',w/A1,inf);
  if ce1<=ce, stop=1; endif;
until(stop);
A1

q3 = max(.5*L/gamma*(A1-w./phis),0);
x3 = q3./phis;



%--------------------productvity-input relationship---------------
eopen('../plots/x_lin_demand.ps',0,180,150,[0,0],1.,1,200,180,0);
eglobpar 
  ePlotAreaPos=[25,25];
  ePlotAreaWidth=150;
  ePlotAreaHeight=120;
  eXAxisNorthVisible=0; 
  eYAxisEastVisible=0;
  eYAxisWestScale=[0 10 55];
  eXAxisSouthScaleType=2;
  eYAxisWestValueVisible=1;
  eXAxisSouthValueVisible=1;
  eAxesValueFontSize=8;
  eAxesLineWidth=.2;
  ePlotLegendTextFont=1;
  ePlotLegendFontSize=9;
  ePlotLegendPos=[95,110];
  etext('\152',.6*eWinWidth,.05*eWinHeight,13,1,13);
  etext('x',.02*eWinWidth,.6*eWinHeight,13,1,4);
  eplot(phis,x1,'Average L',0,[0 0 0],.6);
  eplot(phis,x2,'x0.1',1,[0 0 0],.6);
  eplot(phis,x3,'x10',2,[0 0 0],.6);
eclose;


%---------------productivity-output relationship------------
eopen('../plots/q_lin_demand.ps',0,180,150,[0,0],1.,1,200,180,0);
eglobpar 
  ePlotAreaPos=[25,25];
  ePlotAreaWidth=150;
  ePlotAreaHeight=120;
  eXAxisNorthVisible=0; 
  eYAxisEastVisible=0;
  eYAxisWestScale=[0 2 12];
  eXAxisSouthScaleType=2;
  eYAxisWestValueVisible=1;
  eXAxisSouthValueVisible=1;
  eAxesValueFontSize=8;
  eAxesLineWidth=.2;
  ePlotLegendTextFont=1;
  ePlotLegendFontSize=9;
  ePlotLegendPos=[10,105];
  etext('\152',.6*eWinWidth,.05*eWinHeight,13,1,13);
  etext('q',.02*eWinWidth,.6*eWinHeight,13,1,4);
  eplot(phis,q1,'Average L',0,[0 0 0],.6);
  eplot(phis,q2,'x0.1',1,[0 0 0],.6);
  eplot(phis,q3,'x10',2,[0 0 0],.6);
eclose; 

