%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% x(phi) and q(phi) with trade possibility. Plots Figure 3.          
%% --------------------------------------------------------------------
%%   Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372...                  
%%  By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)                       
%% --------------------------------------------------------------------
%%  This is an Octave m-file (www.octave.org)        
%%  Requires epstk package (esptk.de)
%%  Can be run in MATLAB with some minor changes.                  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;

%---parameters
global A1=201.85; 
global gamma=29.52; 
global A2 markets;
global w=4;  

nphi=150;
phi=logspace(-1,3,nphi); %--range of productivites for display
tau_list = [5,.5];      %---trade costs to be simulated
r0=5;




%-----Expected profit with no trade
function pr=epi(phi);
   global A1 gamma w;
   pr = .25/gamma*(A1-w/phi)^2 * exp(-phi); 
endfunction;
ce = quad('epi',w/A1,inf);  %---entry cost with no trade


%----Expected profit with trade
function pr=epi_t(phi);
   global A2 gamma markets w;
   pr = .25*(A2-w/phi)^2; 
   pr += (A2-(w+markets)/phi).^2 * (phi>=(w+markets)/A2)'; 
   pr = pr/gamma*exp(-phi);
endfunction;



%------------------------------------------------------------
%-------------Loop over trade costs--------------------------

for k=1:length(tau_list),


  tau = tau_list(k);


  %------trade costs for each market
  markets=[];
  for h=0:20,
  for v=1:20,
    markets = [markets, sqrt(h^2+v^2)];
  endfor;
  endfor
  markets = tau*exp(sort(markets,2)/r0);


  %--Find new A so that free-entry holds again
  stop=0;
  A2=A1;
  do;
    A2=A2*.9
    ce1 = quad('epi_t',w/A2,inf);
    if ce1<=ce, stop=1; endif;
  until(stop);
  disp(sprintf('tau=%f ==> A2 = %f',tau,A2));

  %----Generate simulated x and q
  for i=1:nphi,
     %domestic production
     q_trade(k,i) = max(.5*(A2-w/phi(i))/gamma,0);         
     %outside prodution in different markets
     q_trade(k,i) = q_trade(k,i)+2/gamma*(A2-(w+markets)/phi(i)) * (phi(i)>=(w+markets)/A2)'; 
  endfor;
  x_trade(k,:) = q_trade(k,:)./phi;  %%input size


endfor; %---end of k-loop


%----------x and q with no trade
q_domestic = max(.5*(A1-w./phi)/gamma,0); 
x_domestic = q_domestic./phi;


%--------------------productvity-input upper tail---------------
eopen('../plots/x_trade.ps',0,180,150,[0,0],1.,1,200,180,0);
eglobpar 
  ePlotAreaPos=[25,25];
  ePlotAreaWidth=150;
  ePlotAreaHeight=120;
  eXAxisNorthVisible=0; 
  eYAxisEastVisible=0;
  eYAxisWestScale=[0 20 80];
  eXAxisSouthScaleType=2;
  eAxesValueFontSize=8;
  ePlotLegendPos=[100,100];
  ePlotLegendFontSize=9;
  ePlotLegendTextFont=13;
  etext('\152',.6*eWinWidth,.05*eWinHeight,13,1,13);
  etext('x',.02*eWinWidth,.6*eWinHeight,13,1,4);
  eplot(phi,x_trade(1,:),'\164=5',2,[0 0 0],.6);
  eplot(phi,x_trade(2,:),'\164=0.5',0,[0 0 0],.6);
eclose;


%---------------productivity-output upper tail------------
eopen('../plots/q_trade.ps',0,180,150,[0,0],1.,1,200,180,0);
eglobpar 
  ePlotAreaPos=[25,25];
  ePlotAreaWidth=150;
  ePlotAreaHeight=120;
  eXAxisNorthVisible=0; 
  eYAxisEastVisible=0;
  eYAxisWestScale=[0 200 800];
  eXAxisSouthScaleType=2;
  eAxesValueFontSize=8;
  ePlotLegendPos=[20,110];
  ePlotLegendFontSize=9;
  ePlotLegendTextFont=13;
  etext('\152',.6*eWinWidth,.05*eWinHeight,13,1,13);
  etext('q',.02*eWinWidth,.6*eWinHeight,13,1,4);
  eplot(phi,q_trade(1,:),'\164=5',2,[0 0 0],.6);
  eplot(phi,q_trade(2,:),'\164=0.5',0,[0 0 0],.6);
eclose; 


