/*********************************************************
 ***  Eliminating time effect from the panel using      
 ***    Yatchew's method for later non-parametric         
 ***    estimation.     
 *** Yatchew, A. (1998) "Nonparametric Regression Techniques ..." JEL, 36(2), 669                                
 ***--------------------------------------------------- 
 *** Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372.
 *** By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)       
 ***--------------------------------------------------- 
 *** This is a SAS9 file.                               
 *********************************************************/

libname INPUT '../data/';
*options mprint;


********forming the concrete panel data; 
data concrete;  
   set INPUT.concrete(where=(sic87=3273));
   log_te=log(te);
   log_q = log(q);
   wt=round(wt);
   emp_class = round(exp(round(log(emp),.5)));
   keep year emp emp_class wt log_te log_q tfp;
run; 


proc sort data=concrete;
   by emp_class tfp;
run;


************differencing;
data concrete(drop=t8: t9:);
   set concrete;
   by emp_class;

   t82 = (year=1982);
   t87 = (year=1987);
   t92 = (year=1992);
   t97 = (year=1997);
  
   dlog_te = log_te-lag(log_te);
   dlog_q = log_q-lag(log_q);
   dt82 = t82-lag(t82);
   dt87 = t87-lag(t87);
   dt92 = t92-lag(t92);
   dt97 = t97-lag(t97);

   if first.emp_class then do;
      dlog_q=.;
      dlog_te=.;
      dt82=.;
      dt87=.;
      dt92=.;
      dt97=.;
   end;
run;


****************Estimating time effect using OLS;
proc reg data=concrete outest=betas;;
   model dlog_q dlog_te = dt82 dt87 dt92 dt97 / noint;
run;

data betas_te(keep=year Estimate) betas_q(keep=year Estimate);
   set betas;
   if _DEPVAR_='dlog_q' then do;
      year=1982;
      Estimate=dt82;
      output betas_q;
      year=1987;
      Estimate=dt87;
      output betas_q;
      year=1992;
      Estimate=dt92;
      output betas_q;
      year=1997;
      Estimate=dt97;
      output betas_q;
   end;
   if _DEPVAR_='dlog_te' then do;
      year=1982;
      Estimate=dt82;
      output betas_te;
      year=1987;
      Estimate=dt87;
      output betas_te;
      year=1992;
      Estimate=dt92;
      output betas_te;
      year=1997;
      Estimate=dt97;
      output betas_te;
   end;
run;


proc sort data=concrete;
   by year;
run;


*****************Removing time effect from panel data;
data concrete(keep=emp tfp te q wt);
   merge concrete betas_te(rename=(Estimate=b_te)) betas_q(rename=(Estimate=b_q));
   by year;
   log_te = log_te-b_te;
   log_q = log_q-b_q;
   if not (round(wt)=1 and emp=2691);
   if not (round(wt)=2 and emp=2434);
   te = exp(log_te);
   q = exp(log_q);
run;


proc sort data=concrete;
   by tfp emp;
run;


***********************Writting the output file;
proc export data=concrete outfile='../data/concrete.csv'
    dbms=csv replace;
run;



