%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Kernel regressions of output and employment                 
%%%     on productivity and market size. Using kreg.m            
%%%     that makes it possible to use different                  
%%%     bandwidths on different axes.                            
%%%  Generates Figure.4.                                         
%%%--------------------------------------------------------------
%%%  Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372.          
%%% By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)                 
%%%--------------------------------------------------------------
%%% This is an Octave m-file (www.octave.org)                    
%%%   need ESPTK (epstk.de) package to generate graph.           
%%%  Can eb run in MATLAB with soem minor changes.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;

%----reading data
data = dlmread('../data/concrete.csv',",",1,0);

w = data(:,1);
log_tfp = log(data(:,3)/4.92);  %%log of productivity index
te = data(:,4);
q = data(:,5);
log_emp = log(data(:,2));
clear data;

htfp = .5;   %---log(tfp) half-bandwidth
hemp = 2;    %---log(emp) half-bandwidth
index = 3;   
name_te = sprintf("../plots/kreg_te_%d.ps",index);
name_q = sprintf("../plots/kreg_q_%d.ps",index);



%-----prediction data

xdata=[log_tfp,log_emp];
ydata=te;

x1 = (-2.5:.01:1.38)';
x2 = [log(1000);log(10000); log(100000)]; 
n1 = length(x1);
n2 = length(x2);
x=[];
for i=1:n1,
   x = [x;x1(i)*ones(n2,1),x2];
endfor;
clear x1 x2;


%==============================================================
%===   kernel regressions of employment

yhat = kreg(x,ydata,xdata,[htfp;hemp]); 

%-----separating predictions for each market
for i=1:n1,
   x1(i) = x(3*i-2,1);
   y1(i) = yhat(3*i-2);
   x2(i) = x(3*i-1,1);
   y2(i) = yhat(3*i-1);
   x3(i) = x(3*i,1);
   y3(i) = yhat(3*i);
endfor;

x1 = exp(x1);
x2 = exp(x2);
x3 = exp(x3);

%-------plotting predictions
eopen(name_te,0,180,140,[0,0],1.,1,200,160,0);
eglobpar 
  ePlotAreaPos=[20,25]; 
  ePlotAreaWidth=150;
  ePlotAreaHeight=120;
  eXAxisNorthVisible=0; 
  eYAxisEastVisible=0;
  eYAxisWestScale=[5 10 45];
  eAxesLineWidth=.2;
  eAxesTicShortlength=1;
  eAxesTicLongLength=2;
  eXAxisSouthScaleType=2; 
  eAxesValueFontSize=8;
  eAxesLabelFontSize=9;
  eAxesLabelTextFont=14;
  eXAxisSouthLabelText='TFP';
  eYAxisWestLabelText='Employment';
  ePlotLegendPos=[100,110];
  ePlotLegendFontSize=9;
  etext('Market Size',120,145,7)
  eplot(x1,y1,'1,000',0,[0 0 0],.6); 
  eplot(x2,y2,'10,000',1,[0 0 0],.6);
  eplot(x3,y3,'100,000',2,[0 0 0],.6);
eclose;





%==============================================================
%===   kernel regressions of output

ydata=q;

yhat = kreg(x,ydata,xdata,[htfp;hemp]);

%-----separating predictions for each market
for i=1:n1,
   x1(i) = x(3*i-2,1);
   y1(i) = yhat(3*i-2)/1000;
   x2(i) = x(3*i-1,1);
   y2(i) = yhat(3*i-1)/1000;
   x3(i) = x(3*i,1);
   y3(i) = yhat(3*i)/1000;
endfor;

x1 = exp(x1);
x2 = exp(x2);
x3 = exp(x3);

%-------plotting predictions
eopen(name_q,0,180,140,[0,0],1.,1,200,160,0);
eglobpar 
  ePlotAreaPos=[20,25]; 
  ePlotAreaWidth=150;
  ePlotAreaHeight=120;
  eXAxisNorthVisible=0; 
  eYAxisEastVisible=0;
  eYAxisWestScale=[0 1 6.5];
  eAxesLineWidth=.2;
  eAxesTicShortlength=1;
  eAxesTicLongLength=2;
  eXAxisSouthScaleType=2; 
  eAxesValueFontSize=8;
  eAxesLabelFontSize=9;
  eAxesLabelTextFont=14;
  eXAxisSouthLabelText='TFP';
  eYAxisWestLabelText='Real Sales ($mil)';
  eAxesValueFontSize=7;
  eplot(x1,y1,'',0,[0 0 0],.6); 
  eplot(x2,y2,'',1,[0 0 0],.6);
  eplot(x3,y3,'',2,[0 0 0],.6);
eclose;
