/**********************************************************
 *** Semi-parametric regression to find the relation     
 ***    between productivity and output and show the              
 ***    monotonicity.                                    
 ***---------------------------------------------------- 
 *** Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372.
 *** By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)        
 ***---------------------------------------------------- 
 *** This is a SAS9 file.                                
 **********************************************************/

libname DATA '../data/';
options mprint;


****selecting local market industries only; 
data mypanel;  
   set DATA.concrete(where=(sic87=3273));
   log_q=log(q);
   log_tfp = log(tfp/4.92);  ***log of tfp index;
   wt=round(wt);
   keep year emp emp_density wt q log_q log_tfp;
run; 



***************************************************************;
*************Setting up the regression model; 

%let npoly=4;  *degree of polynomial in tfp;


******data file used for predictions;
data scorefile; 
  array p{&npoly};
  year=1992;
  do emp=1000,10000,100000;  
  ***do pp=-2 to 3.5 by 0.05;
  do pp=-3.2 to 1.8 by 0.05;
    do j=1 to &npoly;
     p{j}=pp**j;
    end;
    output; 
  end;
  end;  
run;

data temp(drop=i); 
   set mypanel;
   array p{&npoly};
   do i=1 to &npoly;
      p{i}=log_tfp**i; 
   end;
   emp = round(exp(round(log(emp),.5)));
run;


   ****** Regression Estimation ******; 
proc tpspline data=temp; 
   model log_q = p1 p2 p3 p4 (emp year) / lambda0=1; 
   score data=scorefile out=plotfile; 
   freq wt; 
run; 

proc print data=plotfile;
run;


data pl0 pl1 pl2;  
   set plotfile; 
   q = exp(P_log_q);
   p = exp(p1); 
   select (emp); 
     when (1000) output pl0; 
     when (10000) output pl1;
     when (100000) output pl2; 
     otherwise;
   end; 
   keep p q;
run; 
data plotfile;  ***file to be plotted; 
  merge pl0(rename=(q=q0)) pl1(rename=(q=q1)) 
        pl2(rename=(q=q2));
  by p;
run; 



    ***write prod-size data to output file;
proc export data=plotfile outfile="../data/polyout_tfp.csv"
     dbms=csv replace;
run;

