%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Plots productivity-employment and productivity-output       %
%%%     relations estimated by the semi-parametric method.       %
%%%     input file: poly_tfp.csv                                 %
%%%  Generates Figure.6.                                         %
%%%--------------------------------------------------------------%
%%%  *** Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372.
%%% By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)                 %
%%%--------------------------------------------------------------%
%%% This is an Octave m-file (www.octave.org)                    %
%%%   need ESPTK (epstk.de) package to generate graph.           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;

data = dlmread('../data/poly_tfp.csv',',',1,0);

p = data(:,2);
te0 = data(:,1);
te1 = data(:,3);
te2 = data(:,4);


    %-------plot productivity-input
eopen('../plots/polyin_tfp.ps',0,180,150,[0,0],1.,1,200,180,0);
eglobpar 
  ePlotAreaPos=[25,25];
  ePlotAreaWidth=150;
  ePlotAreaHeight=120;
  eXAxisNorthVisible=0; 
  eYAxisEastVisible=0;
  eYAxisWestScale=[0 10 30];

  eAxesLineWidth=.2;
  eAxesTicShortlength=1;
  eAxesTicLongLength=2;
  eXAxisSouthScaleType=2; 
  eAxesValueFontSize=8;
  eAxesLabelFontSize=9;
  eAxesLabelTextFont=14;
  ePlotLegendPos = [100,100];
  ePlotLegendFontSize=9;

  etext('Market Size',130,135,7);
  eXAxisSouthLabelText='TFP';
  eYAxisWestLabelText='Employment';

  eplot(p,te0,'1,000',0,[0 0 0],.6); 
  eplot(p,te1,'10,000',5,[0 0 0],.6);
  eplot(p,te2,'100,000',1,[0 0 0],.6);

eclose;


%===============================================================
%   productivity-output

data = dlmread('../data/polyout_tfp.csv',',',1,0);

p = data(:,2);
q0 = data(:,1)/1000;
q1 = data(:,3)/1000;
q2 = data(:,4)/1000;

    %-------plot productivity-input
eopen('../plots/polyoutput_tfp.ps',0,180,150,[0,0],1.,1,200,180,0);
eglobpar 
  ePlotAreaPos=[25,25];
  ePlotAreaWidth=150;
  ePlotAreaHeight=120;
  eXAxisNorthVisible=0; 
  eYAxisEastVisible=0;
  eYAxisWestScale=[0 1 4.5];

  eAxesLineWidth=.2;
  eAxesTicShortlength=1;
  eAxesTicLongLength=2;
  eXAxisSouthScaleType=2; 
  eAxesValueFontSize=8;
  eAxesLabelFontSize=9;
  eAxesLabelTextFont=14;
  ePlotLegendPos = [30,100];
  ePlotLegendFontSize=8;

  etext('Market Size',60,135,7);
  eXAxisSouthLabelText='TFP';
  eYAxisWestLabelText='Real Sales ($mil.)';

  eplot(p,q0,'1,000',0,[0 0 0],.6); 
  eplot(p,q1,'10,000',5,[0 0 0],.6);
  eplot(p,q2,'100,000',1,[0 0 0],.6);

eclose;
