/********************************************************
 **** Creating a file with data on concrete and        
 ****   other industries for comparison.               
 **** Coffee, Box, and Ice are used as homogenous      
 ****   product industries.                            
 ****------------------------------------------------  
 *** Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372.
 *** By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)      
 ***-------------------------------------------------- 
 *** This is a SAS9 file.                              
 ********************************************************/

options obs=max; 

libname cm 'd:\data\cm\' access=readonly;
*libname cm '/data/working/04/sasan/tfp/' access=readonly;
libname DATA '../data/';


*********selecting industries;
data DATA.local;
   set cm.mypanel(where=(sic87 in (3273,2097,2095,2653) and 
                               year in (1982,1987,1992,1997)));
   keep state county year wt te q ltfp sic87 age;
run; 


***************List of industries;
proc sort data=DATA.local;
   by sic87;
run;

proc means data=DATA.local vardef=wdf n mean std;
   class sic87;
   var te age;
   weight wt;
   title "Summary statistics on included industries";
run;   

proc univariate data=DATA.local vardef=wdf noprint;
   class sic87;
   var age;
   output out=temp pctlpre=P pctlpts=10 to 30 by 2;
   weight wt;
run;


*************Taking out the fixed effects; 
proc glm data=DATA.local noprint; 
   by sic87;
   class year; 
   model ltfp = year; 
   output out=temp residual=r_ltfp; 
   weight wt;
   quit; 
run;


*************re-adjusting mean;
proc means data=temp noprint; 
   by sic87; 
   output out=means(drop=_TYPE_ _FREQ_) mean(r_ltfp ltfp)=mrtfp mtfp; 
   weight wt; 
run;  

data DATA.local(drop=mtfp mrtfp r_ltfp ltfp); 
   merge temp means; 
   by sic87; 
   tfp = exp(r_ltfp-mrtfp+mtfp);
run;


**************writing output report;
Proc contents data=DATA.local;
  title "final list of the industries";

proc print data=DATA.local (obs=10);
run;
