function density = kde(x_pred, x, h, w);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Function for KDE estimate of x.
%%   x_pred: x's at which kernel estimations will be computed
%%   x : available data
%%   h : bandwidth
%%   w : sample weights (optional)
%% Book: J.S.Simonoff,"Smoothing Methods in Statistics",Springer,1996
%%-------------------------------------------------------------------
%% Written by Sasan Bakhtiari, UNSW, Sydney Australia
%% This is an Octave m-file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    np = size(x_pred,1);
    n  = size(x,1);

    if nargin <3, error('Not enough input arguments!'); endif;
        %--if no weight, use uniform weight
    if nargin == 3, w = ones(n,1);   endif;
    n = sum(w);

    c = 1/sqrt(2*pi);

    for i=1:np,
      
      %---computing kernel weights for each x at x_pred
      %---using Gaussian kernel and bandwidth h
      wd = c*exp(-0.5*(x_pred(i)-x).*(x_pred(i)-x)/(h*h)).*w;
      %---estimating density using the kernel weights
      density(i) = sum(wd)/(n*h);

    endfor;

endfunction;

