function fit = kreg(x_pred, y, x, h, w);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Function for kernel regression of y on x.
%%   x_pred: x's at which kernel estimations will be computed
%%   y : dependent variable
%%   x : independent variable 
%%   h : bandwidth
%%   w : sample weights (optional)
%% Book: J.S.Simonoff,"Smoothing Methods in Statistics",Springer,1996
%%-------------------------------------------------------------------
%% Written by Sasan Bakhtiari, UNSW, Sydney Australia
%% This is an Octave m-file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    n = size(x,1);
    np = size(x_pred,1);

    nx = size(x,2);    %---number of regressors


    %-----------Testing input

        %---tetsing lack of arguments
    if nargin <4, error('Not enough input arguments!'); endif;

        %--if no weight, use uniform weight
    if nargin == 4, w = ones(n,1);   endif;

        %--testing input consistency
    if nx~=size(x_pred,2), error('The number of regressors not the same in x and x_pred'); endif;
    if length(h)~=nx, error('Need the same number of bandwith parameters as regressors'); endif;



    for i=1:np,

      %---using Gaussian kernel and bandwidth h(k) for kth regressor
      for k=1:nx,     
         wd(:,k) = exp(-0.5*(x_pred(i,k)-x(:,k)).*(x_pred(i,k)-x(:,k))/(h(k)*h(k))).*w;
      endfor;

      wd = prod(wd,2);

      %---taking averages using the kernel weights
      fit(i) = sum(wd.*y)/sum(wd);

    endfor;

endfunction;

